@@ -1,6 +1,6 @@
 wCBA <- function(formula, data, support = 0.2, confidence = 0.8,
   verbose=FALSE, parameter = NULL, control = NULL, sort.parameter = NULL, lhs.support=FALSE, class.weights=NULL,
-	disc.method = "cluster", disc.categories = 10){
+	disc.method = "mldp", disc.categories = 10){
 
     return(CBA.internal(formula, data, method="weighted", support = support,
       confidence = confidence, verbose = verbose,
